@@ -1,4 +1,7 @@
-#' tidyjson.
+#' tidyjson
+#' 
+#' The tidyjson package provides tools to turn complex JSON data into 
+#' tidy tibbles and data frames.
 #'
 #' @name tidyjson
 #' @docType package
@@ -21,5 +24,5 @@ if(getRversion() >= "2.15.1")  {
                            "..name", "..json", "setNames",
                            ".", "schemas", "complexity",
                            "..id", "..name1", "..name2", "..type",
-                           "..value", "..suffix", "all.null", "..JSON"))
+                           "..value", "..suffix", "all.null", "..JSON", ":="))
 }
